module.exports = defineTest({
	description: 'does not remove arguments from calls when rest parameters are used'
});
